Carrying out a risk assessment with OiRA | OiRA

Topics

# Carrying out a risk assessment with OiRA

## Starting a new session

To start a new risk assessment, click the link ‘Start a new session’.

## Opening a risk assessment

Once you have started a risk assessment, you can retrieve it at any time through the dashboard under the heading ‘My risk assessments’. Form here you can also start a new risk assessment.

The dashboard.

## Navigating a risk assessment

Each risk assessment guides you through several steps. They are visible in the main menu on the left side of the screen:

- Preparation
- Involvement
- Identification + Evaluation
- Action plan
- Report
- Status

Depending on decisions taken by the OiRA partners/tool developers, the structure of each tool can vary. In some tools, the risk identification and evaluation step includes the action plan. In this case, the menu on the left appears as follows:

- Preparation
- Involvement
- Assessment
- Report
- Status

## Preparation

‘Preparation’ is where you start each session/tool. It is where you give the risk assessment a name that will later help you distinguish between several different risk assessments you have carried out with the tool.

The link ‘Learn more about this tool…’ provides further information on the selected tool and the parties involved in its development.

After clicking ‘Start’, some additional questions may be asked, depending on the tool you are using. This preparatory screen with ‘profile questions’ appears only with tools that offer this option.

Here you can:

- Select or skip situation(s) depending on whether they apply to your business activity. Choose ‘yes’ where appropriate.
- List multiple business units, branches or stores, and so on. The related risks will be repeated for each entry.

The “Profile” screen in the Preparation step

The preparation step is very important as it accurately defines the type of business and the related risks your company deals with. After clicking ‘Save and continue’ you will be led to the next section, ‘Involvement’.

Note: Many tools do not have profile questions as they do not use this feature for targeting the tool. In this case, this screen is automatically skipped.

## Involvement

This step is a reminder of the importance of worker involvement and presents different ways to ensure good worker involvement. Here you can download or print the contents of the risk assessment for sharing with your workers/employees. This ensures that workers are able to contribute to the task of assessing the situation at their workplace.

## Assessment

In this step you will identify hazards and problems relevant to your company.

Note: Depending on how the tool was configured by the OiRA partner, the ‘Action plan’ step (see below) may be integrated into this screen. In this case, the whole step is called ‘Assessment’, and the elements described under ‘Action plan’ will appear under the identification and evaluation of each risk.

Identification and Evaluation.

On the left of the screen, below ‘Identification + Evaluation’/‘Assessment’, you can see each of the topics/modules included in the tool. The topic you are currently viewing is highlighted.

### Identification

For each risk, you have to decide if the statement describing a desired state applies to your company. You can respond as follows:

- Yes: if you respond to the statement with ‘yes’, no further action is needed, as you have assessed the risk as not present.
- No: if you respond to the statement with ‘no’, further action has to be taken. You will be asked to decide on specific measures.
- Not applicable: some risk statements give the option of selecting ‘not applicable’ if the risk is not relevant to your company/establishment.

Below each statement there is usually more information on the specific risk:

- Information: a short description, sometimes with accompanying images, providing more details about the risk.
- Resources: additional information about the risk, such as legal and policy references. Sometimes you can also find documents attached here for further reading.
- Comments: you can put your own comments here, which will appear in your report at the end of the assessment.

After responding to a risk statement and proceeding, the menu on the left will be updated with a coloured symbol to indicate whether you have:

- answered positively (green tick)
- answered negatively (red cross)
- postponed (orange question mark)

For unanswered questions, the grey symbol remains.

### Evaluation

In this step you evaluate the priority of a risk that you have identified.

Evaluating a risk.

Note: In some OiRA tools, the evaluation is not shown. This depends on how the national partner/OiRA tool developer has set up its particular OiRA tool.

If you have identified a risk as being present (shown by a red cross), the section for evaluation will appear. Depending on the evaluation method set for each risk, you will be asked to:

- estimate the priority: high, medium or low

Setting the priority of a risk.

OR

- answer a few questions about the frequency, the severity and the probability of the risk, so that the priority can be calculated based on your answers.

Setting variables for a risk.

### Priority risks set by the sector:

Some risks are considered very important by the national partner/tool developer who created the specific OiRA tool. You are not required to estimate such ‘priority risks’, as their priority will automatically be set to ‘high’.

Priority risks.

### Custom risks

After you have finished answering all risk topics under ‘Identification + Evaluation’/‘Assessment’, you will arrive at the optional topic ‘Other risks’. Here, the button ‘Add a custom risk’ lets you create your own entries.

If there are risks missing in the tool that are present at your workplace/in your company, you need to add them here. These risks can be completely defined/phrased by you.

Custom risks.

A ‘custom risk’ works in a very similar way to the risks provided by the OiRA tool, but obviously you need to write your own text. This text should at least be a short statement that describes a problematic situation, with the option of a longer description. You can also upload an image for illustrating a certain situation.

As with the regular risks, you need to state whether the risk is present or not. This will allow you to tick off the custom risks once you have dealt with them successfully, but keep them in your risk assessment for documentation purposes.

You can add as many custom risks as you need.

Add a custom risk.

## Action plan

In this step, you decide on the measures that you want to implement to eliminate or mitigate the risks that you have previously identified.

Note: As mentioned above, the action plan is presented as a separate step in the menu on the left or appears under each identified risk. In the latter case, the step in the menu is called ‘Assessment’ and includes both the risk statements and a choice of responses.

Which version you are provided with depends on decisions taken by the national OiRA partner/tool developer.

### Integrated action plan

Integrated action plan.

If you answer a question with ‘no’, then the action plan module will unfold on the page, under the heading ‘Measures’.

You can both select from a list of measures proposed by the system and define your own measures.

### Seperate action plan

When the action plan is a separate step, it will be accessible through the left hand navigation.

Click the button ‘Create action plan’ to start your plan.

In the action plan step, the menu on the left now only shows the risks marked for further action, as the other risks were ticked as not being present.

For each risk answered ‘no’ during the evaluation process and for priority risks (regardless of whether they were answered positively or negatively) you will be asked to define measures.

A risk in the action plan.

You can either select from a list of measures suggested by the system or define your own measures.

#### Add your own measure

Adding an extra measure.

Use the button ‘Add a measure’ to start defining a preventive measure. You should:

- Describe the general approach that will be taken to eliminate or reduce the risk.
- Optionally state the level of expertise and/or requirements needed (e.g. here you can add if specific training or external expertise is needed to deal with this risk)
- Enter information on who is responsible for the implementation.
- Define a budget, if applicable.
- Optionally set dates for when to start implementing the measure and when you plan to complete it.

You can add as many measures as needed.

#### Add standard measures

Depending on how the OiRA partner/tool developer has set up the tool, predefined measures are available for individual risks. To choose one or more predefined measures, click the button ‘Select standard measures’.

A pop-up menu opens that displays all the suggested measures. Click the ‘Add’ button for the ones that you want to use.

The predefined measures are then listed in your action plan. The description of what to do is fixed, but the other fields (responsibility, budget, dates) can and should be filled in by you.

Adding standard measures.

Both standard measures and measures defined by you can be deleted again at any point.

## Report

After finalising the action plan, you can produce a report.

If you want to leave a comment to be included in the report, type your text here and save it.

Comment the report.

See here to read more about the different reports and how to use them.

## Status

The small pie chart in the menu on the left shows you the progress you have made with the tool.

The status section provides an overview of how many risks you have identified, how many of them you have addressed by deciding on measures and how many risks/statements you have still not responded to.

The status page.

When you enter the status screen, you can see how far you have progressed in each module. This can help you note where you still need to assess risks or provide measures for those risks that you have identified.

Scroll to top Load toolbar…
Back

## 3-carrying-out-a-risk-assessment.md

More…

- New risk assessment
- Show archived risk assessments
- All types of risk assessments Only regular risk assessments Only contractor risk assessments

Help

Standard search Advanced search

- Splash and Shine Cleaners Last saved 19 days ago based on EU Cleaning More
- Commercial Guardinng, Leicester Last saved 2 months ago based on Private Security EU More
- Private Security, Grafton Street Last saved 2 months ago based on Private Security EU More
- Office operations in times of COVID-19 Last saved 4 months ago based on COVID-19 More